# -*- coding: utf-8 -*-
# Generated by Django 1.11.18 on 2019-02-02 20:17
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_presskit', '0003_auto_20181002_1915'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='additionallink',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='award',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='companyimageattachment',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='companylogoattachment',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='companyvideo',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='contact',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='credit',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='feature',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='platform',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='price',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='project',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='projectimageattachment',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='projectlogoattachment',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='quote',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='social',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AlterModelOptions(
            name='trailer',
            options={'ordering': ['my_order', 'datetime_updated']},
        ),
        migrations.AddField(
            model_name='additionallink',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='award',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='companyimageattachment',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='companylogoattachment',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='companyvideo',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='contact',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='credit',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='feature',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='platform',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='price',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='project',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='projectimageattachment',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='projectlogoattachment',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='quote',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='social',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name='trailer',
            name='my_order',
            field=models.PositiveIntegerField(default=0),
        ),
    ]
