# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-10-02 18:47
from __future__ import unicode_literals

from django.db import migrations

def create_monetizations(apps, schema_editor):
    # We can't import the Person model directly as it may be a newer
    # version than this migration expects. We use the historical version.
    MonetizationPermission = apps.get_model('django_presskit', 'MonetizationPermission')

    MonetizationPermission(option='False', description='The contents of this project are not allowed to be published through video broadcasting services.'
      ).save()
    MonetizationPermission(option='Ask', description='The contents of this project may be published through video broadcasting services with written permission.'
      ).save()
    MonetizationPermission(option='Non-Commercial', description='The contents of this project may be published through video broadcasting services for non-commercial purposes only. Monetization is not allowed without written permission.'
      ).save()
    MonetizationPermission(option='Monetize', description='The contents of this project may be published through video broadcasting services and these videos may be monetized.'
      ).save()

class Migration(migrations.Migration):

    dependencies = [
        ('django_presskit', '0001_initial'),
    ]

    operations = [
        migrations.RunPython(create_monetizations),
    ]
