# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-10-02 19:15
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_presskit', '0002_auto_20181002_1847'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='company',
            name='promoter_id',
        ),
        migrations.RemoveField(
            model_name='project',
            name='distribute_keyfile',
        ),
        migrations.RemoveField(
            model_name='project',
            name='promoter_id',
        ),
        migrations.AddField(
            model_name='project',
            name='distribute_access_hash',
            field=models.CharField(blank=True, help_text='The access hash from your Distribute() keyfile (https://dodistribute.com/access/add/THIS-HASH/)', max_length=25, null=True),
        ),
        migrations.AddField(
            model_name='project',
            name='distribute_game_id',
            field=models.CharField(blank=True, help_text='The game ID from your Distribute() keyfile (https://dodistribute.com/games/presskit/THIS-ID/)', max_length=25, null=True),
        ),
        migrations.AddField(
            model_name='project',
            name='distribute_key',
            field=models.CharField(blank=True, help_text='The key from your Distribute() keyfile filename (ds_THIS-KEY)', max_length=80, null=True),
        ),
    ]
