# -*- coding: utf-8 -*-
# Generated by Django 1.11.14 on 2018-10-02 18:41
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import filer.fields.file
import filer.fields.image


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('filer', '0010_auto_20180414_2058'),
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='AdditionalLink',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=200)),
                ('slug', models.SlugField(unique=True)),
                ('description', models.TextField(blank=True, null=True)),
                ('website', models.URLField()),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Attachment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content', filer.fields.image.FilerImageField(on_delete=django.db.models.deletion.CASCADE, to=settings.FILER_IMAGE_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='Award',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(max_length=200)),
                ('info', models.CharField(blank=True, max_length=1000, null=True)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Company',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=200)),
                ('slug', models.SlugField(unique=True)),
                ('website', models.URLField(blank=True, null=True)),
                ('based_in', models.CharField(blank=True, max_length=400, null=True)),
                ('description', models.TextField(blank=True, null=True)),
                ('history', models.TextField(blank=True, null=True)),
                ('analytics', models.CharField(blank=True, help_text='Your Google Analytics ID', max_length=200, null=True)),
                ('promoter_id', models.CharField(blank=True, help_text='A product ID in Promoter with quotes for your company', max_length=20, null=True)),
                ('founding_date', models.CharField(blank=True, max_length=200, null=True)),
                ('press_contact', models.EmailField(blank=True, help_text='The primary press contact email for your company', max_length=200, null=True)),
                ('phone', models.CharField(blank=True, max_length=50, null=True)),
                ('address', models.TextField(blank=True, null=True)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('additional_links', models.ManyToManyField(blank=True, to='django_presskit.AdditionalLink')),
                ('awards', models.ManyToManyField(blank=True, to='django_presskit.Award')),
            ],
            options={
                'verbose_name_plural': 'companies',
            },
        ),
        migrations.CreateModel(
            name='CompanyImageAttachment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('attachment', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Attachment')),
                ('company', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Company')),
            ],
        ),
        migrations.CreateModel(
            name='CompanyLogoAttachment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('attachment', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Attachment')),
                ('company', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Company')),
            ],
        ),
        migrations.CreateModel(
            name='CompanyVideo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=400)),
                ('embed_url', models.URLField(blank=True, null=True)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('company', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='videos', to='django_presskit.Company')),
                ('file', filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='company_video', to='filer.File')),
            ],
        ),
        migrations.CreateModel(
            name='Contact',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=300)),
                ('website', models.URLField(blank=True, null=True)),
                ('email', models.EmailField(blank=True, max_length=254, null=True)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Credit',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('person', models.CharField(max_length=300)),
                ('website', models.URLField(blank=True, null=True)),
                ('role', models.TextField(blank=True, null=True)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Feature',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(max_length=1000)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='MonetizationPermission',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('option', models.CharField(max_length=200)),
                ('description', models.CharField(max_length=500)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Platform',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('website', models.URLField(blank=True, null=True)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Price',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('price', models.CharField(max_length=200)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Project',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=200)),
                ('slug', models.SlugField(unique=True)),
                ('release_date', models.CharField(max_length=200)),
                ('website', models.URLField()),
                ('description', models.TextField()),
                ('history', models.TextField()),
                ('press_can_request_copy', models.BooleanField()),
                ('promoter_id', models.CharField(blank=True, max_length=20, null=True)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('additional_links', models.ManyToManyField(blank=True, to='django_presskit.AdditionalLink')),
                ('awards', models.ManyToManyField(blank=True, to='django_presskit.Award')),
                ('company', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Company')),
                ('contacts', models.ManyToManyField(blank=True, to='django_presskit.Contact')),
                ('credits', models.ManyToManyField(blank=True, to='django_presskit.Credit')),
                ('distribute_keyfile', filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='project_distribute_keyfile', to='filer.File')),
                ('header_image', filer.fields.image.FilerImageField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='project_header_image', to=settings.FILER_IMAGE_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='ProjectImageAttachment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('attachment', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Attachment')),
                ('project', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Project')),
            ],
        ),
        migrations.CreateModel(
            name='ProjectLogoAttachment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('attachment', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Attachment')),
                ('project', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Project')),
            ],
        ),
        migrations.CreateModel(
            name='Quote',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('reviewer', models.CharField(max_length=400)),
                ('website', models.URLField()),
                ('publication_name', models.CharField(max_length=400)),
                ('description', models.TextField()),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Social',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200)),
                ('website', models.URLField()),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('company', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Company')),
            ],
        ),
        migrations.CreateModel(
            name='Trailer',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=400)),
                ('embed_url', models.URLField(blank=True, null=True)),
                ('datetime_created', models.DateTimeField(auto_now_add=True)),
                ('datetime_updated', models.DateTimeField(auto_now=True)),
                ('file', filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='trailer_video', to='filer.File')),
                ('project', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='videos', to='django_presskit.Project')),
            ],
        ),
        migrations.AddField(
            model_name='project',
            name='images',
            field=models.ManyToManyField(related_name='project_images', through='django_presskit.ProjectImageAttachment', to='django_presskit.Attachment'),
        ),
        migrations.AddField(
            model_name='project',
            name='logos',
            field=models.ManyToManyField(related_name='project_logos', through='django_presskit.ProjectLogoAttachment', to='django_presskit.Attachment'),
        ),
        migrations.AddField(
            model_name='project',
            name='monetization_permission',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.MonetizationPermission'),
        ),
        migrations.AddField(
            model_name='project',
            name='quotes',
            field=models.ManyToManyField(blank=True, to='django_presskit.Quote'),
        ),
        migrations.AddField(
            model_name='price',
            name='project',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Project'),
        ),
        migrations.AddField(
            model_name='platform',
            name='project',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Project'),
        ),
        migrations.AddField(
            model_name='feature',
            name='project',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='django_presskit.Project'),
        ),
        migrations.AddField(
            model_name='company',
            name='contacts',
            field=models.ManyToManyField(blank=True, to='django_presskit.Contact'),
        ),
        migrations.AddField(
            model_name='company',
            name='credits',
            field=models.ManyToManyField(blank=True, to='django_presskit.Credit'),
        ),
        migrations.AddField(
            model_name='company',
            name='header_image',
            field=filer.fields.image.FilerImageField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='company_header_image', to=settings.FILER_IMAGE_MODEL),
        ),
        migrations.AddField(
            model_name='company',
            name='images',
            field=models.ManyToManyField(related_name='company_images', through='django_presskit.CompanyImageAttachment', to='django_presskit.Attachment'),
        ),
        migrations.AddField(
            model_name='company',
            name='logos',
            field=models.ManyToManyField(related_name='company_logos', through='django_presskit.CompanyLogoAttachment', to='django_presskit.Attachment'),
        ),
        migrations.AddField(
            model_name='company',
            name='quotes',
            field=models.ManyToManyField(blank=True, to='django_presskit.Quote'),
        ),
    ]
