# -*- coding: utf-8 -*-
# Generated by Django 1.11.13 on 2019-04-02 11:06
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_presskit', '0004_auto_20190202_2017'),
        ('django_presskit', '0004_auto_20190123_0157'),
    ]

    operations = [
    ]
